require "import"
import "android.widget.*"
import "android.content.*"
import "android.view.*"
import "com.androlua.*"

local rutaArchivo = "/storage/emulated/0/PortapapelesUltra/notas.txt"
local notas = {}

-- Función para cargar notas
function cargarNotas()
  notas = {}
  local archivo = io.open(rutaArchivo, "r")
  if archivo then
    local lineaActual = {}
    for linea in archivo:lines() do
      if linea == "" then
        table.insert(notas, {titulo = lineaActual[1], texto = lineaActual[2] or ""})
        lineaActual = {}
      else
        table.insert(lineaActual, linea)
      end
    end
    io.close(archivo)
  end
end

-- Función para guardar nota
function guardarNota(titulo, texto)
  os.execute("mkdir -p /storage/emulated/0/PortapapelesUltra")
  local archivo = io.open(rutaArchivo, "a")
  if archivo then
    archivo:write(titulo.."\n"..texto.."\n\n")
    io.close(archivo)
    service.asyncSpeak("Texto guardado.")
  end
end

-- Función para copiar texto
function copiarTexto(txt)
  local clip = service.getSystemService(Context.CLIPBOARD_SERVICE)
  clip.setPrimaryClip(ClipData.newPlainText("Texto", txt))
  service.asyncSpeak("Texto copiado al portapapeles.")
end

-- Crear texto
function crearTexto()
  local layout = {
    LinearLayout,
    orientation = "vertical",
    padding = "16dp",
    {
      EditText,
      id = "titulo",
      hint = "Título",
      layout_width = "match_parent",
      layout_height = "wrap_content",
    },
    {
      EditText,
      id = "contenido",
      hint = "Contenido del texto",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      lines = 6,
    },
    {
      Button,
      text = "Guardar",
      onClick = function()
        local t = titulo.Text
        local c = contenido.Text
        if t ~= "" and c ~= "" then
          guardarNota(t, c)
          dlgCrear.dismiss()
        else
          service.asyncSpeak("Falta título o contenido.")
        end
      end
    }
  }

  dlgCrear = LuaDialog(service)
  dlgCrear.View = loadlayout(layout)
  dlgCrear.show()
end

-- Mostrar textos guardados
function verTextos()
  cargarNotas()
  local layout = {
    ScrollView,
    layout_width = "match_parent",
    layout_height = "match_parent",
    {
      LinearLayout,
      orientation = "vertical",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      padding = "8dp"
    }
  }

  local contenedor = layout[2]

  for _, nota in ipairs(notas) do
    table.insert(contenedor, {
      Button,
      text = nota.titulo,
      layout_width = "match_parent",
      layout_height = "wrap_content",
      onClick = function()
        mostrarNota(nota)
        dlgLista.dismiss()
      end
    })
  end

  dlgLista = LuaDialog(service)
  dlgLista.View = loadlayout(layout)
  dlgLista.show()
end

-- Mostrar contenido individual
function mostrarNota(nota)
  local layout = {
    LinearLayout,
    orientation = "vertical",
    padding = "16dp",
    {
      TextView,
      text = nota.titulo,
      textSize = "18sp",
    },
    {
      TextView,
      text = nota.texto,
      textSize = "16sp",
    },
    {
      Button,
      text = "Copiar",
      onClick = function()
        copiarTexto(nota.texto)
        dlgNota.dismiss()
      end
    }
  }

  dlgNota = LuaDialog(service)
  dlgNota.View = loadlayout(layout)
  dlgNota.show()
end

-- Menú principal
local layoutMenu = {
  LinearLayout,
  orientation = "vertical",
  padding = "16dp",
  {
    Button,
    text = "Crear texto",
    layout_width = "match_parent",
    onClick = function()
      crearTexto()
      dlgMenu.dismiss()
    end
  },
  {
    Button,
    text = "Ver textos guardados",
    layout_width = "match_parent",
    onClick = function()
      verTextos()
      dlgMenu.dismiss()
    end
  }
}

dlgMenu = LuaDialog(service)
dlgMenu.View = loadlayout(layoutMenu)
dlgMenu.show()